Modular Forms
=============

Modular Forms for Arithmetic Groups
-----------------------------------

.. toctree::
   :maxdepth: 1

   sage/modular/modform/constructor
   sage/modular/modform/space
   sage/modular/modform/ambient
   sage/modular/modform/ambient_eps
   sage/modular/modform/ambient_g0
   sage/modular/modform/ambient_g1
   sage/modular/modform/ambient_R
   sage/modular/modform/submodule
   sage/modular/modform/cuspidal_submodule
   sage/modular/modform/eisenstein_submodule
   sage/modular/modform/eis_series
   sage/modular/modform/eis_series_cython
   sage/modular/modform/element
   sage/modular/modform/hecke_operator_on_qexp
   sage/modular/modform/numerical
   sage/modular/modform/vm_basis
   sage/modular/modform/half_integral
   sage/modular/modform/ring
   sage/modular/modform/j_invariant
   sage/modular/modform/theta

   sage/modular/modform/notes

Modular Forms for Hecke Triangle Groups
---------------------------------------

.. toctree::
   :maxdepth: 1

   sage/modular/modform_hecketriangle/readme

   sage/modular/modform_hecketriangle/abstract_ring
   sage/modular/modform_hecketriangle/abstract_space

   sage/modular/modform_hecketriangle/element
   sage/modular/modform_hecketriangle/graded_ring_element

   sage/modular/modform_hecketriangle/constructor
   sage/modular/modform_hecketriangle/functors

   sage/modular/modform_hecketriangle/hecke_triangle_groups
   sage/modular/modform_hecketriangle/hecke_triangle_group_element
   sage/modular/modform_hecketriangle/analytic_type

   sage/modular/modform_hecketriangle/graded_ring
   sage/modular/modform_hecketriangle/space
   sage/modular/modform_hecketriangle/subspace

   sage/modular/modform_hecketriangle/series_constructor

Drinfeld Modular Forms
----------------------

.. toctree::
   :maxdepth: 1

   sage/modular/drinfeld_modform/tutorial
   sage/modular/drinfeld_modform/ring
   sage/modular/drinfeld_modform/element

Quasimodular Forms
------------------

.. toctree::
   :maxdepth: 1

   sage/modular/quasimodform/ring
   sage/modular/quasimodform/element

Miscellaneous Modules (to be sorted)
------------------------------------

.. toctree::
   :maxdepth: 1

   sage/modular/dirichlet
   sage/modular/cusps
   sage/modular/dims
   sage/modular/buzzard

   sage/modular/local_comp/local_comp
   sage/modular/local_comp/smoothchar
   sage/modular/local_comp/type_space
   sage/modular/local_comp/liftings

   sage/modular/etaproducts
   sage/modular/overconvergent/weightspace
   sage/modular/overconvergent/genus0
   sage/modular/overconvergent/hecke_series
   sage/modular/ssmod/ssmod
   sage/modular/quatalg/brandt
   sage/modular/cusps_nf
   sage/modular/hypergeometric_motive
   sage/modular/hypergeometric_misc
   sage/modular/multiple_zeta
   sage/modular/modform/l_series_gross_zagier_coeffs

.. include:: ../footer.txt
